==> savane-1.0.3.1.tar.gz: savane/frontend/php/my/bookmark_edit.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: bookmark_edit.php,v 1.13 2004/03/13 18:22:06 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#
#  Copyright 2004      (c) ...
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";

site_user_header(array('title'=>_("Edit"),'toptab'=>'bookmark'));

print '<h3>'._("Edit Bookmark").'</h3>';

if ($bookmark_url && $bookmark_title) 
{
	bookmark_edit($bookmark_id, $bookmark_url, $bookmark_title);
}

$result = db_query("SELECT * from user_bookmarks where "
	. "bookmark_id='".$bookmark_id."' and user_id='".user_getid()."'");
if ($result) 
{
	$bookmark_url = db_result($result,0,'bookmark_url');
	$bookmark_title = db_result($result,0,'bookmark_title');
}

echo '<FORM METHOD="POST">';
echo _("Bookmark URL:").'<br>';
echo '<input type="text" name="bookmark_url" value="'.$bookmark_url.'">';
echo '<p>';
echo _("Bookmark Title:").'<br>';
echo '<input type="text" name="bookmark_title" value="'.$bookmark_title.'"></p>';
echo '<p>';
echo '<input type="submit" value=" '._("Submit Form").' ">';
echo '</form>';

print "<p><a href=\"".$GLOBALS['sys_home']."my/\">"._("Return")."</a></p>";

site_user_footer(array());

?>

==> savane-1.0.5a.tar.gz: savane/frontend/php/my/bookmark_edit.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: bookmark_edit.php,v 1.14 2004/09/22 08:11:51 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#
#  Copyright 2004      (c) ...
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";

site_user_header(array('title'=>_("Edit"),'toptab'=>'bookmark'));

print '<h3>'._("Edit Bookmark").'</h3>';

if ($bookmark_url && $bookmark_title) 
{
	bookmark_edit($bookmark_id, $bookmark_url, $bookmark_title);
}

$result = db_query("SELECT * from user_bookmarks where "
	. "bookmark_id='".$bookmark_id."' and user_id='".user_getid()."'");
if ($result) 
{
	$bookmark_url = db_result($result,0,'bookmark_url');
	$bookmark_title = db_result($result,0,'bookmark_title');
}

echo '<FORM METHOD="POST">';
echo _("Bookmark URL:").'<br />';
echo '<input type="text" name="bookmark_url" value="'.$bookmark_url.'">';
echo '<p>';
echo _("Bookmark Title:").'<br />';
echo '<input type="text" name="bookmark_title" value="'.$bookmark_title.'"></p>';
echo '<p>';
echo '<input type="submit" value=" '._("Submit Form").' ">';
echo '</form>';

print "<p><a href=\"".$GLOBALS['sys_home']."my/\">"._("Return")."</a></p>";

site_user_footer(array());

?>
